translate.storage.rc

Package translate :: Package storage :: Module rc |
[hide private]
[frames] | no frames]

# Module rc

source code

Classes that hold units of .rc files (rcunit) or entire files (rcfile) used in translating Windows Resources.

Note: This implementation is based mostly on observing WINE .rc files, these should mimic other non-WINE .rc files.

Classes | [hide private]
| rcunit A unit of an rc file
| rcfile This class represents a .rc file, made up of rcunits.

Functions | [hide private]
escape_to_python(string) escape a given .rc string into a valid Python string | source code
escape_to_rc(string) Escape a given Python string into a valid .rc string. | source code

Imports: base, re